# remirepo/fedora spec file for php-pecl-rdkafka4
#
# Copyright (c) 2015-2019 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%if 0%{?scl:1}
%global sub_prefix %{scl_prefix}
%scl_package       php-pecl-rdkafka
%endif

%global with_zts   0%{!?_without_zts:%{?__ztsphp:1}}
%global pecl_name  rdkafka
%global with_tests %{?_without_tests:0}%{!?_without_tests:1}
%global ini_name   40-%{pecl_name}.ini

%global buildver %(pkg-config --silence-errors --modversion rdkafka 2>/dev/null || echo 65536)

Summary:        Kafka client based on librdkafka
Name:           %{?sub_prefix}php-pecl-%{pecl_name}4
Version:        4.0.1
Release:        1%{?dist}%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}
License:        MIT
URL:            http://pecl.php.net/package/%{pecl_name}
Source0:        http://pecl.php.net/get/%{pecl_name}-%{version}.tgz

BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  librdkafka-devel >= 0.11
BuildRequires:  %{?scl_prefix}php-devel > 5.6
BuildRequires:  %{?scl_prefix}php-pear

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}
Requires:       librdkafka%{?_isa}  >= %{buildver}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
%if "%{?scl_prefix}" != "%{?sub_prefix}"
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}
%endif

%if 0%{?fedora} >= 31 || 0%{?rhel} >= 9 || "%{php_version}" > "7.4"
Obsoletes:     %{?scl_prefix}php-pecl-%{pecl_name}          < 4
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:      %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}
%else
# A single version can be installed
Conflicts:     %{?scl_prefix}php-pecl-%{pecl_name}          < 4
%endif

%if "%{?vendor}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
# Other third party repo stuff
%if "%{php_version}" > "7.1"
Obsoletes:     php71u-pecl-%{pecl_name} <= %{version}
Obsoletes:     php71w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.2"
Obsoletes:     php72u-pecl-%{pecl_name} <= %{version}
Obsoletes:     php72w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.3"
Obsoletes:      php73-pecl-%{pecl_name} <= %{version}
Obsoletes:     php73w-pecl-%{pecl_name} <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:      php74-pecl-%{pecl_name} <= %{version}
Obsoletes:     php74w-pecl-%{pecl_name} <= %{version}
%endif
%endif

%if 0%{?fedora} < 20 && 0%{?rhel} < 7
# Filter shared private
%{?filter_provides_in: %filter_provides_in %{_libdir}/.*\.so$}
%{?filter_setup}
%endif


%description
This extension is a librdkafka binding providing a working client for Kafka.

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -q -c
mv %{pecl_name}-%{version} NTS

# Don't install tests
sed -e 's/role="test"/role="src"/' \
    %{?_licensedir:-e '/LICENSE/s/role="doc"/role="src"/' } \
    -i package.xml

cd NTS
# Sanity check, really often broken
extver=$(sed -n '/#define PHP_RDKAFKA_VERSION/{s/.* "//;s/".*$//;p}' php_rdkafka.h)
if test "x${extver}" != "x%{version}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat > %{ini_name} << 'EOF'
; Enable %{pecl_name} extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

cd NTS
%{_bindir}/phpize
%configure \
    --with-php-config=%{_bindir}/php-config \
    --with-rdkafka
make %{?_smp_mflags}

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
%configure \
    --with-php-config=%{_bindir}/zts-php-config \
    --with-rdkafka
make %{?_smp_mflags}
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%check
cd NTS
: Minimal load test for NTS extension
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}
%endif


%files
%{?_licensedir:%license NTS/LICENSE}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Mon Dec  9 2019 Remi Collet <remi@remirepo.net> - 4.0.1-1
- update to 4.0.1

* Sat Oct  5 2019 Remi Collet <remi@remirepo.net> - 4.0.0-1
- update to 4.0.0
- rename to php-pecl-rdkafka4
- raise dependency on librdkafka 0.11

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 3.1.2-2
- rebuild for 7.4.0RC1

* Tue Jul  9 2019 Remi Collet <remi@remirepo.net> - 3.1.2-1
- update to 3.1.2

* Mon Jul  8 2019 Remi Collet <remi@remirepo.net> - 3.1.1-2
- add upstream patch to fix PHP 5.6 build

* Wed Jul  3 2019 Remi Collet <remi@remirepo.net> - 3.1.1-1
- update to 3.1.1
- open https://github.com/arnaud-lb/php-rdkafka/issues/235
  broken build with PHP 5.6 (ZVAL_DEREF)

* Tue Jun 25 2019 Remi Collet <remi@remirepo.net> - 3.1.0-2
- rebuild with librdkafka 0.11 in EL-8

* Thu Apr 18 2019 Remi Collet <remi@remirepo.net> - 3.1.0-1
- update to 3.1.0
- raise dependency on PHP 5.6

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 3.0.5-3
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 3.0.5-2
- rebuild for 7.3.0alpha4 new ABI

* Mon Nov 20 2017 Remi Collet <remi@remirepo.net> - 3.0.5-1
- Update to 3.0.5

* Wed Aug 23 2017 Remi Collet <remi@remirepo.net> - 3.0.4-2
- EL-7 rebuild using librdkafka in EPEL

* Wed Aug 16 2017 Remi Collet <remi@remirepo.net> - 3.0.4-1
- Update to 3.0.4

* Tue Jul 18 2017 Remi Collet <remi@remirepo.net> - 3.0.3-4
- rebuild for PHP 7.2.0beta1 new API

* Wed Jun 21 2017 Remi Collet <remi@remirepo.net> - 3.0.3-2
- rebuild for 7.2.0alpha2

* Mon May 29 2017 Remi Collet <remi@remirepo.net> - 3.0.3-1
- Update to 3.0.3

* Wed May 24 2017 Remi Collet <remi@remirepo.net> - 3.0.2-1
- Update to 3.0.2 (stable)

* Sat Jan 28 2017 Remi Collet <remi@fedoraproject.org> - 3.0.1-1
- Update to 3.0.1

* Mon Dec 19 2016 Remi Collet <remi@fedoraproject.org> - 3.0.0-1
- update to 3.0.0 (php 5 and 7, stable)
- open https://github.com/arnaud-lb/php-rdkafka/issues/98 failed build
  fixed by https://github.com/arnaud-lb/php-rdkafka/pull/99

* Thu Dec  1 2016 Remi Collet <remi@fedoraproject.org> - 2.0.1-2
- rebuild with PHP 7.1.0 GA

* Mon Nov 28 2016 Remi Collet <remi@fedoraproject.org> - 2.0.1-1
- Update to 2.0.1

* Wed Sep 14 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-2
- rebuild for PHP 7.1 new API version

* Fri Sep 09 2016 Remi Collet <remi@fedoraproject.org> - 2.0.0-1
- Update to 2.0.0 (php 7)
- open https://github.com/arnaud-lb/php-rdkafka/issues/71

* Fri Sep 09 2016 Remi Collet <remi@fedoraproject.org> - 1.0.0-1
- Update to 1.0.0 (php 5)

* Tue Mar  8 2016 Remi Collet <remi@fedoraproject.org> - 0.9.1-2
- adapt for F24

* Mon Jan 11 2016 Remi Collet <remi@fedoraproject.org> - 0.9.1-1
- Update to 0.9.1 (beta)

* Sat Jan 09 2016 Remi Collet <remi@fedoraproject.org> - 0.9.0-1
- Update to 0.9.0 (beta)

* Thu May 14 2015 Remi Collet <remi@fedoraproject.org> - 0.0.2-1
- initial package, version 0.0.2 (alpha)
- open https://github.com/arnaud-lb/php-rdkafka/pull/5 - ZTS build
- open https://github.com/arnaud-lb/php-rdkafka/pull/4 - License
